Aggregates data extract selectors
get_dplyr_call_data.RdSimplifies selector_list into aggregated list with one element per same selector - same dataset, same filter configuration and same reshape status
Usage
get_dplyr_call_data(selector_list, join_keys = list())Arguments
- selector_list
(
reactive)
output fromdata_extract_multiple_srv()or a reactive named list of outputs fromdata_extract_srv(). When using a reactive named list, the names must be identical to the shiny ids of the respectivedata_extract_ui().- join_keys
(named
list) nested list of keys used for joining