Gets keys needed for join call of two selectors
get_merge_key_i(
selector_list,
idx,
dplyr_call_data = get_dplyr_call_data(selector_list)
)character list of keys.
(reactive)
output from data_extract_multiple_srv() or a reactive named list of
outputs from data_extract_srv().
When using a reactive named list, the names must be identical to the shiny
ids of the respective
data_extract_ui().
(integer) optional, current selector index in all selectors list.
(list) simplified selectors with aggregated set of filters.