list_extract_spec: Make sure that the extract specification is in list format

View source: R/input_checks.R

list_extract_specR Documentation

Make sure that the extract specification is in list format

Description

Make sure that the extract specification is in list format

Usage

list_extract_spec(x, allow_null = FALSE)

Arguments

x

(data_extract_spec or list) of data_extract_spec elements.

allow_null

(logical) whether x can be NULL.

Value

x as a list if it is not already.


teal.transform documentation built on June 29, 2026, 9:08 a.m.